@@ -4,7 +4,7 @@ plot.proLik <- function(x, CL = TRUE, alpha = 0.05, type = "l", ...)
 
   plot(x$lambdas ~ x$var.estimates, 
      xlab = x$component, ylab = "LRT statistic", 
-     type = "l", lwd = 2, ...)
+     type = type, lwd = 2, ...)
      if(CL){  
         chi <- (-0.5 * qchisq(alpha, df = 1, lower.tail = FALSE))
         abline(h = chi, lty = "dotted", col = "red", lwd = 2)
